@@ -22,7 +22,7 @@ from pocsuite3.modules.censys import Censys
 from pocsuite3.modules.ceye import CEye
 from pocsuite3.modules.fofa import Fofa
 from pocsuite3.modules.httpserver import PHTTPServer
-from pocsuite3.modules.listener import (REVERSE_PAYLOAD, bind_shell,
+from pocsuite3.modules.listener import (REVERSE_PAYLOAD, BIND_PAYLOAD, bind_shell,
                                         bind_tcp_shell, bind_telnet_shell)
 from pocsuite3.modules.quake import Quake
 from pocsuite3.modules.hunter import Hunter
@@ -39,8 +39,8 @@ __all__ = ('requests', 'PluginBase', 'register_plugin', 'PLUGIN_TYPE',
            'DEFAULT_LISTENER_PORT', 'load_file_to_module', 'OrderedDict', 'OrderedSet',
            'load_string_to_module', 'single_time_warn_message', 'CEye',
            'Seebug', 'ZoomEye', 'Shodan', 'Fofa', 'Quake', 'Hunter', 'Censys',
-           'PHTTPServer', 'REVERSE_PAYLOAD', 'get_listener_ip', 'mosaic', 'urlparse',
-           'get_listener_port', 'get_results', 'init_pocsuite',
+           'PHTTPServer', 'REVERSE_PAYLOAD', 'BIND_PAYLOAD', 'get_listener_ip', 'mosaic',
+           'urlparse', 'get_listener_port', 'get_results', 'init_pocsuite',
            'start_pocsuite', 'get_poc_options', 'crawl', 'OSShellcodes',
            'WebShell', 'OptDict', 'OptIP', 'OptPort', 'OptBool', 'OptInteger',
            'OptFloat', 'OptString', 'OptItems', 'get_middle_text',
