@@ -17,7 +17,7 @@ from pocsuite3.lib.core.common import boldify_message, check_file, get_file_item
 from pocsuite3.lib.core.common import check_path, extract_cookies
 from pocsuite3.lib.core.common import get_local_ip, mosaic, get_host_ip
 from pocsuite3.lib.core.common import single_time_warn_message
-from pocsuite3.lib.core.common import OrderedSet
+from pocsuite3.lib.core.common import OrderedSet, get_file_text
 from pocsuite3.lib.core.convert import stdout_encode
 from pocsuite3.lib.core.data import conf, cmd_line_options
 from pocsuite3.lib.core.data import kb
@@ -350,12 +350,11 @@ def _set_pocs_modules():
                         _pocs.extend(map(lambda x: os.path.join(root, x), files))
 
                 for p in _pocs:
-                    file_content = open(p, encoding='utf-8').read()
-                    if 'register_poc' not in file_content:
+                    file_content = get_file_text(p)
+                    if not re.search(r'register_poc', file_content):
                         continue
                     if conf.poc_keyword:
-                        attr_field = re.search(r'vulID.*?def .*?\(', file_content, re.DOTALL)
-                        if attr_field and conf.poc_keyword.lower() not in attr_field.group().lower():
+                        if not re.search(conf.poc_keyword, file_content, re.I | re.M):
                             continue
                     info_msg = "loading PoC script '{0}'".format(p)
                     logger.info(info_msg)
